@@ -5,10 +5,12 @@
 import sys
 import os
 import re
+import shlex
 import tempfile
 import shutil
 import urllib
 import glob
+import imp
 from optparse import OptionParser
 
 from dbtexmf.core.confparser import DbtexConfig, texinputs_parse, texstyle_parse
@@ -340,14 +342,12 @@ class DbTex:
                 donefiles.sort()
                 self.log.info("Files successfully built in '%s':\n%s" % \
                               (self.outputdir, "\n".join(donefiles)))
-        except Exception, e:
-            signal_error(self, e)
-
-        os.chdir(self.cwdir)
-        if not(self.debug):
-            shutil.rmtree(self.tmpdir)
-        else:
-            self.log.info("%s not removed" % self.tmpdir)
+        finally:
+            os.chdir(self.cwdir)
+            if not(self.debug):
+                shutil.rmtree(self.tmpdir)
+            else:
+                self.log.info("%s not removed" % self.tmpdir)
 
     def _stdin_write(self):
         # Find out the stdin working directory
@@ -382,10 +382,15 @@ class DbTex:
 
         # For easy debug
         if self.debug and os.environ.has_key("TEXINPUTS"):
-            f = file("env_tex", "w")
-            f.write("TEXINPUTS=%s\nexport TEXINPUTS\n" % \
-                    os.environ["TEXINPUTS"])
-            f.close()
+            if os.name != "nt":
+                f = file("env_tex", "w")
+                f.write("TEXINPUTS=%s\nexport TEXINPUTS\n" % \
+                        os.environ["TEXINPUTS"])
+                f.close()
+            else:
+                f = file("env_tex.bat", "w")
+                f.write("set TEXINPUTS=%s\n" % os.environ["TEXINPUTS"])
+                f.close()
 
         # Build the tex file(s), and compile it(them)
         self.make_listings()
@@ -498,6 +503,19 @@ class DbTexCommand:
         # The actual engine to use is unknown
         self.run = None
 
+    def load_plugin(self, pathname):
+        moddir, modname = os.path.split(pathname)
+        try:
+            filemod, path, descr = imp.find_module(modname, [moddir])
+        except ImportError:
+            try:
+                filemod, path, descr = imp.find_module(modname)
+            except ImportError:
+                failed_exit("Error: '%s' module not found" % modname)
+        mod = imp.load_module(modname, filemod, path, descr)
+        filemod.close()
+        return mod
+
     def run_setup(self, options):
         run = self.run
 
@@ -522,7 +540,8 @@ class DbTexCommand:
             failed_exit("Error: %s" % e)
 
         if options.xslopts:
-            run.xslopts = options.xslopts
+            for o in options.xslopts:
+                run.xslopts += shlex.split(o)
 
         if options.xslparams:
             run.xslparams += options.xslparams
@@ -574,9 +593,13 @@ class DbTexCommand:
                 run.xslusers.append(xsluser)
 
         if options.texpost:
-            path = os.path.realpath(options.texpost)
-            if not(os.path.isfile(path)):
-                failed_exit("Error: '%s' does not exist" % options.texpost)
+            is_plugin = options.texpost.startswith("plugin:")
+            if is_plugin:
+                path = self.load_plugin(options.texpost[len("plugin:"):])
+            else:
+                path = os.path.realpath(options.texpost)
+                if not(os.path.isfile(path)):
+                    failed_exit("Error: '%s' does not exist" % options.texpost)
             run.texpost = path
 
         if options.no_external:
@@ -695,5 +718,6 @@ class DbTexCommand:
         try:
             run.compile()
         except Exception, e:
+            signal_error(self, e)
             failed_exit("Error: %s" % e)
 
